@@ -5,8 +5,7 @@ UVICORN_WORKERS="${UVICORN_MAX_WORKERS:=10}"
 
 set -ep
 
-uv run webhook_server_container/utils/github_repository_settings.py
-uv run webhook_server_container/utils/webhook.py
+uv run webhook_server_container/utils/github_repository_and_webhook_settings.py
 
 if [[ -z $DEVELOPMENT ]]; then
   eval "${SERVER_RUN_CMD} --workers ${UVICORN_WORKERS}"
